@@ -448,6 +448,7 @@ class EnemyDeathType(str, Enum):
     STAND = "stand"
     EFFECT = "effect"
     WAIT = "wait"
+    ENERGY = "energy"
 
 
 ENEMY_DEATH_TYPE_NAME: dict[int, EnemyDeathType] = {
@@ -455,6 +456,7 @@ ENEMY_DEATH_TYPE_NAME: dict[int, EnemyDeathType] = {
     2: EnemyDeathType.STAND,
     3: EnemyDeathType.EFFECT,
     4: EnemyDeathType.WAIT,
+    5: EnemyDeathType.ENERGY,
 }
 
 
